@@ -1,5 +1,6 @@
 import argparse
 import numpy as np
+import sys
 from fair_dynamic_rec.core.config_cmd import ConfigCmd
 from fair_dynamic_rec.core.data_cmd import DataCmd
 from pathlib import Path
@@ -11,6 +12,7 @@ from fair_dynamic_rec.core.visualization_cmd import VisualizationCmd
 from fair_dynamic_rec.core.metric_cmd import MetricCmd
 from datetime import datetime
 from fair_dynamic_rec.core.util.ranker_utils import set_rankers
+# import multiprocessing as mp
 
 def read_args():
     '''
@@ -58,15 +60,22 @@ if __name__ == '__main__':
     # purge_old_logs(args['target'] + "/*")
     log_name = create_log_name('FairDynamicRec_log{}.log')
     args['log_name'] = log_name
-    print(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ": Start loading config.")
+    # print(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ": Start loading config.")
     config = load_config(args)
-    print(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ": Config loaded.")
+    # print(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ": Config loaded.")
 
     dataObj = DataCmd(config)
     print("#users: " + str(dataObj.n_users) + ", #items: " + str(dataObj.n_items) + ", #train_ratings:" + str(np.count_nonzero(dataObj.train_data)) + ", #test_ratings:" + str(np.count_nonzero(dataObj.test_data)))
+    print("#items: " + str(dataObj.item_data.shape[0]) + ", #cats: " + str(dataObj.item_data.shape[1]) + ", #itemCats:" + str(np.count_nonzero(dataObj.item_data)))
+    sys.stdout.flush()
 
+    # print(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ": Start setting rankers.")
+    sys.stdout.flush()
     rankers = set_rankers(config, dataObj)
+    # print(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ": Rankers set.")
+    sys.stdout.flush()
 
+    # pool = mp.Pool(config.processor_count)
     if args['action'] == 'run':
         sim = OnlineSimulator(config, dataObj)
         sim.run(config, dataObj, rankers)
