@@ -307,8 +307,8 @@ class DataCmd:
             index_ones = np.asarray(np.where(u_vec != 0))[0]
             np.random.shuffle(index_ones)
             train_size = int(len(index_ones) * ratio)
-            test_data[u][index_ones[:train_size]] = rating_data[u][index_ones[:train_size]]
-            train_data[u][index_ones[train_size:]] = rating_data[u][index_ones[train_size:]]
+            test_data[u][index_ones[train_size:]] = rating_data[u][index_ones[train_size:]]
+            train_data[u][index_ones[:train_size]] = rating_data[u][index_ones[:train_size]]
         return train_data, test_data
     def save_data_as_txt_file(self, config):
         save_data, train_file_name, test_file_name = config.get_save_txt_data_info()
